# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2007-2009 David Douard (Paris, FRANCE).
http://www.logilab.org/project/pygpibtoolkit -- mailto:david.douard@logilab.fr

"""
import mx.DateTime as dt

from pygpibtoolkit.pygpib import Constants, Command
from pygpibtoolkit.pygpib import Mode, ModeCommand
from pygpibtoolkit.pygpib import VoltageValue
from pygpibtoolkit.pygpib import WriteOnlyMode

from pygpibtoolkit.gpibcontroller import AbstractGPIBDevice, deviceRegister

class _VoltageValue(VoltageValue):
    _units = "VL","MV","UV"

class APA(_VoltageValue):
    "CHAN A AMP - Channel A amplitude"
class APB(_VoltageValue):
    "CHAN A AMP - Channel A amplitude"
class APC(_VoltageValue):
    "CHAN A AMP - Channel A amplitude"
class APD(_VoltageValue):
    "CHAN A AMP - Channel A amplitude"

class Backlight(WriteOnlyMode):
    "Backlight"
    _init_value = "BO"

    BF = ModeCommand("Off", "OFF")
    BO = ModeCommand("On", "ON")

class _PerOutputMode(WriteOnlyMode):
    
    def __init__(self):
        self._cmds = []
        for cmdname, cmd in self.__class__.__dict__.items():
            if isinstance(cmd, ModeCommand):
                self._cmds.append(self._prefix + cmdname)

    def build_set_cmd(self, value):
        # XXX HERE: todo: make it work with value not in self._cmds
        # (eg. value=="AU", cmds == ['FS1AU')
        assert value in self._cmds
        return value, value

    
class Filter1(_PerOutputMode):
    "Filter for output 1"
    _prefix = "FS1"
    _init_value = "AU"
    SH = ModeCommand("Elliptic (sharp cutoff)", "ELIPT.")
    LO = ModeCommand("Gaussian (low overshoot)", "GAUSS.")
    AU = ModeCommand("Automatic", "AUTO")

class Filter2(Filter1):
    "Filter for output 2"
    _prefix = "FS2"
    
    
class HP8904Device(AbstractGPIBDevice):
    _accepts = ["^(?P<model>HP *8904A).*$",]
    _idn = "ID"

    def __init__(self, idn, address, controller):
        super(HP8904Device, self).__init__(idn, address, controller)

        
deviceRegister.register_manager(HP8904Device)
